@@ -28,7 +28,10 @@ def get_response(code, body):
     if type(body) in [dict, list]:
         return {
             "statusCode": code,
-            "body": json.dumps(body)
+            "body": json.dumps(body),
+            "headers": {
+                "Content-Type": "application/json"
+            }
         }
     else:
         return {
@@ -36,6 +39,7 @@ def get_response(code, body):
             "body": body
         }
 
+
 def get_debug_msg(*args):
     msg = "*** debug ***\n"
     for i in args:
